@@ -27,12 +27,20 @@
 #include <stdarg.h>
 #include "RawListener.h"
 
+#ifdef _U
+#undef _U
+#endif
+
 #define _U(M, L) \
 	if (!m_printCallgraphScore) \
 			__iuprintf M; \
 	else \
 		m_callStack.push(L);
 
+#ifdef _D
+#undef _D
+#endif
+
 #define _D(M, L) \
 	if (!m_printCallgraphScore) \
 			__idprintf M; \
@@ -47,14 +55,15 @@
 RawListenerImpl::RawListenerImpl(bool printCallgraphScore) :
 	m_indent(0),
 	m_callbackMisses(0),
-	m_printCallgraphScore(printCallgraphScore)
+	m_printCallgraphScore(printCallgraphScore),
+	m_callStack()
 {
 }
 
 RawListenerImpl::~RawListenerImpl()
 {
 	if (m_printCallgraphScore)
-		printf("%d\n", m_callStack.size() + m_callbackMisses);
+		printf("%d\n", (int)(m_callStack.size() + m_callbackMisses));
 }
 
 void RawListenerImpl::__iprintf(const char *format, ...)
@@ -100,7 +109,7 @@ WPXString getPropString(const WPXPropertyList &propList)
 		WPXString prop;
 		prop.sprintf("%s: %s", i.key(), i()->getStr().cstr());
 		propString.append(prop);
-		for (i; i.next(); )
+		for (; i.next(); )
 		{
 			prop.sprintf(", %s: %s", i.key(), i()->getStr().cstr());
 			propString.append(prop);
@@ -123,7 +132,7 @@ WPXString getPropString(const WPXPropertyListVector &itemList)
 		propString.append(getPropString(i()));
 		propString.append(")");
 
-		for (i; i.next();)
+		for (; i.next();)
 		{
 			propString.append(", (");
 			propString.append(getPropString(i()));
