@@ -29,6 +29,7 @@
 #include "libwpd_internal.h"
 #include "WP3SubDocument.h"
 #include <algorithm>
+#include <limits>
 
 _WP3ContentParsingState::_WP3ContentParsingState():
 	m_colSpan(1),
@@ -73,15 +74,57 @@ void WP3ContentListener::insertCharacter(const uint16_t character)
 	}
 }
 
-void WP3ContentListener::insertTab(const uint8_t /* tabType */, float /* tabPosition */)
+void WP3ContentListener::insertTab()
 {
         if (!isUndoOn())
 	{
-		if (!m_ps->m_isSpanOpened)
-			_openSpan();
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			if (m_ps->m_tabStops.empty() || (_getNextTabStop() == (std::numeric_limits<float>::max)()))
+				m_ps->m_textIndentByTabs += 0.5f;
+			else
+				m_ps->m_textIndentByTabs = _getNextTabStop() - (m_ps->m_leftMarginByTabs  + m_ps->m_textIndentByParagraphIndentChange);
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+		}
 		else
-			_flushText();
-		m_listenerImpl->insertTab();
+		{
+			if (!m_ps->m_isSpanOpened)
+				_openSpan();
+			else
+				_flushText();
+			m_listenerImpl->insertTab();
+		}
+	}
+}
+
+void WP3ContentListener::insertTab(const uint8_t tabType, const float /* tabPosition */)
+{
+	if (!isUndoOn())
+	{
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			switch (tabType)
+			{
+			case WP3_TAB_GROUP_CENTER:
+				m_ps->m_tempParagraphJustification = WPX_PARAGRAPH_JUSTIFICATION_CENTER;
+				return;
+			case WP3_TAB_GROUP_FLUSH_RIGHT:
+				m_ps->m_tempParagraphJustification = WPX_PARAGRAPH_JUSTIFICATION_RIGHT;
+				return;
+			default:
+				insertTab();
+				return;
+			}
+		}
+		else
+			insertTab();
 	}
 }
 
@@ -569,7 +612,13 @@ void WP3ContentListener::insertNote(const WPXNoteType noteType, WP3SubDocument *
 {
 	if (!isUndoOn() && !m_ps->m_isNote)
 	{
-		_closeSpan();
+		if (!m_ps->m_isParagraphOpened)
+			_openParagraph();
+		else
+		{
+			_flushText();
+			_closeSpan();
+		}
 		m_ps->m_isNote = true;
 		WPXNumberingType numberingType = _extractWPXNumberingTypeFromBuf(m_parseState->m_noteReference, ARABIC);
 		int number = _extractDisplayReferenceNumberFromBuf(m_parseState->m_noteReference, numberingType);
@@ -593,6 +642,142 @@ void WP3ContentListener::insertNote(const WPXNoteType noteType, WP3SubDocument *
 	}
 }
 
+void WP3ContentListener::backTab()
+{
+	if (!isUndoOn() && !m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+	{
+		if (m_ps->m_tabStops.empty() || (_getPreviousTabStop() == (std::numeric_limits<float>::max)()))
+			m_ps->m_textIndentByTabs -= 0.5f;
+		else
+			m_ps->m_textIndentByTabs = _getPreviousTabStop() - (m_ps->m_leftMarginByTabs  + m_ps->m_textIndentByParagraphIndentChange);
+
+		m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+			+ m_ps->m_textIndentByTabs;
+		m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+			+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+		m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+			+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+		m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+	}
+}
+
+void WP3ContentListener::leftIndent()
+{
+	if (!isUndoOn())
+	{
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			if (m_ps->m_tabStops.empty() || (_getNextTabStop() == (std::numeric_limits<float>::min)()))
+				m_ps->m_leftMarginByTabs += 0.5f;
+			else
+				m_ps->m_leftMarginByTabs = _getNextTabStop() - (m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange);
+
+			if (m_ps->m_paragraphTextIndent != 0.0f)
+				m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
+
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+		}
+		else
+			insertTab();
+	}
+}
+
+void WP3ContentListener::leftIndent(const float offset)
+{
+	if (!isUndoOn())
+	{
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			if (offset == 0.0f)
+				m_ps->m_leftMarginByTabs += 0.5f;
+			else
+				m_ps->m_leftMarginByTabs += (offset / 72.0f);
+
+			if (m_ps->m_paragraphTextIndent != 0.0f)
+				m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
+
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+		}
+		else
+			insertTab();
+	}
+}
+
+void WP3ContentListener::leftRightIndent()
+{
+	if (!isUndoOn())
+	{
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			if (m_ps->m_tabStops.empty() || (_getNextTabStop() == (std::numeric_limits<float>::min)()))
+				m_ps->m_leftMarginByTabs += 0.5f;
+			else
+				m_ps->m_leftMarginByTabs = _getNextTabStop() - (m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange);
+			
+			if (m_ps->m_paragraphTextIndent != 0.0f)
+				m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
+
+			m_ps->m_rightMarginByTabs = m_ps->m_leftMarginByTabs;
+
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+		}
+		else
+			insertTab();
+	}
+}
+
+void WP3ContentListener::leftRightIndent(const float offset)
+{
+	if (!isUndoOn())
+	{
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			if (offset == 0.0f)
+				m_ps->m_leftMarginByTabs += 0.5f;
+			else
+				m_ps->m_leftMarginByTabs += (offset / 72.0f);
+
+			if (m_ps->m_paragraphTextIndent != 0.0f)
+				m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
+
+			m_ps->m_rightMarginByTabs = m_ps->m_leftMarginByTabs;
+
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+		}
+		else
+			insertTab();
+	}
+}
+
 void WP3ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter,
 						WPXTableList /* tableList */, int /* nextTableIndice */)
 {
