@@ -1,7 +1,8 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
- * Copyright (C) 2005-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
+ * Copyright (C) 2005-2007 Fridrich Strba (fridrich.strba@bluewin.ch)
+ * Copyright (C) 2007 Novell, Inc. (http://www.novell.com)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -68,14 +69,155 @@ void WP5ContentListener::insertCharacter(const uint16_t character)
 	appendUCS4(m_parseState->m_textBuffer, (uint32_t)character);
 }
 
-void WP5ContentListener::insertTab(const uint8_t /* tabType */, float /* tabPosition */)
+void WP5ContentListener::insertTab(const uint8_t tabType, const float tabPosition)
 {
-	if (!m_ps->m_isSpanOpened)
-		_openSpan();
-	else
-		_flushText();
+	bool tmpHasTabPositionInformation = true;
+	if (tabPosition >= (float)((double)0xFFFE/(double)WPX_NUM_WPUS_PER_INCH) || tabPosition == 0.0f)
+		tmpHasTabPositionInformation = false;
 
-	m_listenerImpl->insertTab();
+	if (!isUndoOn())
+	{
+		switch ((tabType & 0xE8) >> 3)
+		{
+		case WP5_TAB_GROUP_CENTER_TAB:
+		case WP5_TAB_GROUP_RIGHT_TAB:
+		case WP5_TAB_GROUP_DECIMAL_TAB:
+			if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+				if (m_ps->m_currentListLevel == 0)
+					_openParagraph();
+				else
+					_openListElement();
+			break;
+
+		default:
+			break;
+		}
+
+		// Following tabs are converted as formating if the paragraph is not opened
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			switch ((tabType & 0xE8) >> 3)
+			{
+			case WP5_TAB_GROUP_CENTER_ON_MARGINS:
+			case WP5_TAB_GROUP_CENTER_ON_CURRENT_POSITION:
+				m_ps->m_tempParagraphJustification = WPX_PARAGRAPH_JUSTIFICATION_CENTER;
+				break;
+
+			case WP5_TAB_GROUP_FLUSH_RIGHT:
+				m_ps->m_tempParagraphJustification = WPX_PARAGRAPH_JUSTIFICATION_RIGHT;
+				break;
+
+			case WP5_TAB_GROUP_LEFT_TAB: // converted as first line indent
+				if (!tmpHasTabPositionInformation)
+					m_ps->m_textIndentByTabs += 0.5f;
+				else
+					m_ps->m_textIndentByTabs = tabPosition - m_ps->m_paragraphMarginLeft - m_ps->m_pageMarginLeft 
+						- m_ps->m_sectionMarginLeft - m_ps->m_textIndentByParagraphIndentChange;
+				break;
+
+			case WP5_TAB_GROUP_BACK_TAB: // converted as hanging indent
+				if (!tmpHasTabPositionInformation)
+					m_ps->m_textIndentByTabs -= 0.5f;
+				else
+					m_ps->m_textIndentByTabs = tabPosition - m_ps->m_paragraphMarginLeft - m_ps->m_pageMarginLeft
+						- m_ps->m_sectionMarginLeft - m_ps->m_textIndentByParagraphIndentChange;
+				break;
+
+			default:
+				break;
+			}
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+
+		}
+		else
+		{
+			if (!m_ps->m_isSpanOpened)
+				_openSpan();
+			else
+				_flushText();
+
+			switch ((tabType & 0xF8) >> 3)
+			{
+			case WP5_TAB_GROUP_LEFT_TAB:
+			case WP5_TAB_GROUP_CENTER_ON_MARGINS:
+			case WP5_TAB_GROUP_CENTER_ON_CURRENT_POSITION:
+			case WP5_TAB_GROUP_CENTER_TAB:
+			case WP5_TAB_GROUP_FLUSH_RIGHT:
+			case WP5_TAB_GROUP_RIGHT_TAB:
+			case WP5_TAB_GROUP_DECIMAL_TAB:
+				m_listenerImpl->insertTab();
+				break;
+			
+			default:
+				break;
+			}
+		}
+	}
+}
+
+void WP5ContentListener::insertIndent(const uint8_t indentType, const float indentPosition)
+{
+	bool tmpHasIndentPositionInformation = true;
+	if (indentPosition >= (float)((double)0xFFFE/(double)WPX_NUM_WPUS_PER_INCH) || indentPosition == 0.0f)
+		tmpHasIndentPositionInformation = false;
+
+	if (!isUndoOn())
+	{
+		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
+		{
+			switch (indentType & 0x01)
+			{
+			case WP5_INDENT_GROUP_LEFT_INDENT:  // converted as left paragraph margin offset
+				if (!tmpHasIndentPositionInformation)
+					m_ps->m_leftMarginByTabs += 0.5f;
+				else
+					m_ps->m_leftMarginByTabs = indentPosition - m_ps->m_pageMarginLeft - m_ps->m_sectionMarginRight
+						- m_ps->m_leftMarginByPageMarginChange - m_ps->m_leftMarginByParagraphMarginChange;
+				if (m_ps->m_paragraphTextIndent != 0.0f)
+					m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
+				break;
+
+			case WP5_INDENT_GROUP_LEFT_RIGHT_INDENT: // converted as left and right paragraph margin offset
+				if (!tmpHasIndentPositionInformation)
+					m_ps->m_leftMarginByTabs += 0.5f;
+				else
+					m_ps->m_leftMarginByTabs = indentPosition - m_ps->m_pageMarginLeft - m_ps->m_sectionMarginLeft
+						- m_ps->m_leftMarginByPageMarginChange - m_ps->m_leftMarginByParagraphMarginChange;
+				m_ps->m_rightMarginByTabs = m_ps->m_leftMarginByTabs;
+				if (m_ps->m_paragraphTextIndent != 0.0f)
+					m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
+				break;	
+				
+			default:
+				break;
+			}
+			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
+				+ m_ps->m_textIndentByTabs;
+			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
+				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
+				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+			
+			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
+
+		}
+		else
+		{
+			if (!m_ps->m_isSpanOpened)
+				_openSpan();
+			else
+				_flushText();
+
+			m_listenerImpl->insertTab();
+		}
+	}
 }
 
 void WP5ContentListener::insertEOL()
@@ -353,6 +495,16 @@ void WP5ContentListener::setFont(const WPXString &fontName, const float fontSize
 	}
 }
 
+void WP5ContentListener::setTabs(const std::vector<WPXTabStop> &tabStops, const uint16_t tabOffset)
+{
+	if (!isUndoOn())
+	{
+		m_ps->m_isTabPositionRelative = ((tabOffset & 0xffff) != 0xffff);
+		m_ps->m_tabStops = tabStops;
+	}
+}
+
+
 void WP5ContentListener::insertNoteReference(const WPXString &noteReference)
 {
 	if (!isUndoOn() && !m_ps->m_isNote)
@@ -365,7 +517,13 @@ void WP5ContentListener::insertNote(const WPXNoteType noteType, const WP5SubDocu
 {
 	if (!isUndoOn())
 	{
-		_closeSpan();
+		if (!m_ps->m_isParagraphOpened)
+			_openParagraph();
+		else
+		{
+			_flushText();
+			_closeSpan();
+		}
 		m_ps->m_isNote = true;
 		WPXNumberingType numberingType = _extractWPXNumberingTypeFromBuf(m_parseState->m_noteReference, ARABIC);
 		int number = _extractDisplayReferenceNumberFromBuf(m_parseState->m_noteReference, numberingType);
