@@ -1,7 +1,8 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
- * Copyright (C) 2005 Fridrich Strba (fridrich.strba@bluewin.ch)
+ * Copyright (C) 2005-2007 Fridrich Strba (fridrich.strba@bluewin.ch)
+ * Copyright (C) 2007 Novell, Inc. (http://www.novell.com)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -54,6 +55,8 @@ extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 
 /* Main function group list  */
 #define WP5_TOP_EXTENDED_CHARACTER 0xC0
+#define WP5_TOP_TAB_GROUP 0xC1
+#define WP5_TOP_INDENT_GROUP 0xC2
 #define WP5_TOP_ATTRIBUTE_ON 0xC3
 #define WP5_TOP_ATTRIBUTE_OFF 0xC4
 #define WP5_TOP_PAGE_FORMAT_GROUP 0xD0
@@ -68,6 +71,7 @@ extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 /* Page Format Group */
 #define WP5_TOP_PAGE_FORMAT_GROUP_LEFT_RIGHT_MARGIN_SET 0x01
 #define WP5_TOP_PAGE_FORMAT_GROUP_SPACING_SET 0x02
+#define WP5_TOP_PAGE_FORMAT_GROUP_TAB_SET 0x04
 #define WP5_TOP_PAGE_FORMAT_GROUP_TOP_BOTTOM_MARGIN_SET 0x05
 #define WP5_TOP_PAGE_FORMAT_GROUP_JUSTIFICATION 0x06
 #define WP5_TOP_PAGE_FORMAT_GROUP_SUPPRESS_PAGE_CHARACTERISTICS 0x07
@@ -81,7 +85,6 @@ extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP5_PAGE_GROUP_SUPPRESS_FOOTER_B 0x20
 #define WP5_PAGE_GROUP_SUPPRESS_CODE_NOT_AT_TOP_OF_PAGE 0x80
 
-
 /* Font Group */
 #define WP5_TOP_FONT_GROUP_COLOR 0x00
 #define WP5_TOP_FONT_GROUP_FONT_CHANGE 0x01
@@ -141,4 +144,19 @@ extern int WP5_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP5_NUM_CYRILLIC_CHARACTERS 150
 #define WP5_NUM_JAPANESE_CHARACTERS 185
 
+/* Tab Group */
+#define WP5_TAB_GROUP_LEFT_TAB 0x00
+#define WP5_TAB_GROUP_DECIMAL_TAB 0x08
+#define WP5_TAB_GROUP_RIGHT_TAB 0x09
+#define WP5_TAB_GROUP_FLUSH_RIGHT 0x0C
+#define WP5_TAB_GROUP_BACK_TAB 0x10
+#define WP5_TAB_GROUP_CENTER_ON_CURRENT_POSITION 0x18
+#define WP5_TAB_GROUP_CENTER_TAB 0x19
+#define WP5_TAB_GROUP_CENTER_ON_MARGINS 0x1C
+
+/* Indent Group */
+#define WP5_INDENT_GROUP_LEFT_INDENT 0x00
+#define WP5_INDENT_GROUP_LEFT_RIGHT_INDENT 0x01
+
+
 #endif /* WP5FILESTRUCTURE_H */
