@@ -1166,7 +1166,13 @@ void WP6ContentListener::noteOn(const uint16_t textPID)
 			return;
 		}
 
-		_closeSpan();
+		if (!m_ps->m_isParagraphOpened)
+			_openParagraph();
+		else
+		{
+			_flushText();
+			_closeSpan();
+		}
 		m_parseState->m_styleStateSequence.setCurrentState(DOCUMENT_NOTE);
 		// save a reference to the text PID, we want to parse
 		// the packet after we're through with the footnote ref.
@@ -1303,7 +1309,9 @@ void WP6ContentListener::startTable()
 			_openSection();
 			m_ps->m_sectionAttributesChanged = false;
 		}
-		_openTable();
+		if (!m_parseState->m_currentTable->isEmpty()) // WordPerfect ignores empty tables and inserts an Hard EOL instead
+			_openTable();
+			
 	}
 }
 
