@@ -1,6 +1,6 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -35,16 +35,14 @@ class WP6GeneralTextPacket : public WP6PrefixDataPacket
 {
 public:
 	WP6GeneralTextPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
-	virtual ~WP6GeneralTextPacket();
-	virtual void _readContents(WPXInputStream *input);
-	virtual void parse(WP6Listener *listener) const;
-	virtual WP6SubDocument * getSubDocument() const { return m_subDocument;}
-
-private:              
-	uint16_t m_numTextBlocks;
-	uint32_t m_firstTextBlockOffset;
-	uint32_t *m_blockSizes;
+	~WP6GeneralTextPacket();
+	void _readContents(WPXInputStream *input);
+	void parse(WP6Listener *listener) const;
+	WP6SubDocument * getSubDocument() const { return m_subDocument;}
 
+private:
+	WP6GeneralTextPacket(const WP6GeneralTextPacket&);             
+	WP6GeneralTextPacket& operator=(const WP6GeneralTextPacket&);             
 	WP6SubDocument * m_subDocument;
 	
 };
