@@ -27,17 +27,13 @@
 #ifndef WP6LISTENER_H
 #define WP6LISTENER_H
  
-#include "WPXPageSpan.h"
-#include "WPXHLListenerImpl.h"
-#include "WP6FileStructure.h"
-
-#include "WP6PrefixDataPacket.h"
+#include "libwpd_internal.h"
 #include <vector>
-#include <list>
 
 class WPXString;
 class WP6DefaultInitialFontPacket;
 class WP6PrefixData;
+class WP6PrefixDataPacket;
 
 enum WP6OutlineLocation { paragraphGroup, indexHeader };
 
@@ -48,9 +44,11 @@ public:
 	virtual ~WP6Listener() {};
 
 	virtual void startDocument() = 0;
-	virtual void setDate(const uint16_t year, const uint8_t month, const uint8_t day,
-			     const uint8_t hour, const uint8_t minute, const uint8_t second,
-			     const uint8_t dayOfWeek, const uint8_t timeZone, const uint8_t unused) = 0;
+	virtual void setDate(const uint16_t type, const uint16_t year, 
+                     const uint8_t month, const uint8_t day, 
+                     const uint8_t hour, const uint8_t minute, 
+                     const uint8_t second, const uint8_t dayOfWeek, 
+                     const uint8_t timeZone, const uint8_t unused) = 0;
 	virtual void setExtendedInformation(const uint16_t type, const WPXString &data) = 0;
 	virtual void setAlignmentCharacter(const uint16_t character) = 0;
 	virtual void setLeaderCharacter(const uint16_t character, const uint8_t numSpaces) = 0;
@@ -70,8 +68,7 @@ public:
 	virtual void attributeChange(const bool isOn, const uint8_t attribute) = 0;
 	virtual void spacingAfterParagraphChange(const float spacingRelative, const float spacingAbsolute) = 0;
 	virtual void pageMarginChange(const uint8_t side, const uint16_t margin) = 0;
-	virtual void pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation,
-				const bool isPersistent) = 0;
+	virtual void pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation) = 0;
 	virtual void marginChange(const uint8_t side, const uint16_t margin) = 0;
 	virtual void paragraphMarginChange(const uint8_t side, const int16_t margin) = 0;
 	virtual void indentFirstLineChange(const int16_t offset) = 0;
@@ -109,6 +106,8 @@ public:
 	const WP6PrefixDataPacket * getPrefixDataPacket(const int prefixID) const;
 		
 private:
+	WP6Listener(const WP6Listener&);
+	WP6Listener& operator=(const WP6Listener&);
 	WP6PrefixData *m_prefixData;
 };
 
