@@ -26,6 +26,7 @@
 #include "WPXPageSpan.h"
 #include "libwpd_internal.h"
 #include "WPXProperty.h"
+#include <limits>
 
 _WPXContentParsingState::_WPXContentParsingState() :
 	m_textAttributeBits(0),
@@ -298,7 +299,8 @@ void WPXContentListener::_openPageSpan()
 	std::vector<WPXHeaderFooter> headerFooterList = currentPage.getHeaderFooterList();
 	for (std::vector<WPXHeaderFooter>::iterator iter = headerFooterList.begin(); iter != headerFooterList.end(); iter++)
 	{
-		if (!currentPage.getHeaderFooterSuppression((*iter).getInternalType()))
+		if (((*iter).getOccurence() != NEVER) && ((*iter).getInternalType() != DUMMY_INTERNAL_HEADER_FOOTER)
+			&& !currentPage.getHeaderFooterSuppression((*iter).getInternalType()))
 		{
 			propList.clear();
 			switch ((*iter).getOccurence())
@@ -322,7 +324,9 @@ void WPXContentListener::_openPageSpan()
 			else
 				m_listenerImpl->openFooter(propList); 
 
+			WPD_DEBUG_MSG(("Header Footer Element: Starting to parse the subDocument\n"));
 			handleSubDocument((*iter).getSubDocument(), true, (*iter).getTableList(), 0);
+			WPD_DEBUG_MSG(("Header Footer Element: End of the subDocument parsing\n"));
 			if ((*iter).getType() == HEADER)
 				m_listenerImpl->closeHeader();
 			else
@@ -591,10 +595,10 @@ void WPXContentListener::_openSpan()
 
 	if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
 		_changeList();
-		if (m_ps->m_currentListLevel == 0)
-			_openParagraph();
-		else
-			_openListElement();
+	if (m_ps->m_currentListLevel == 0)
+		_openParagraph();
+	else
+		_openListElement();
 	
 	// The behaviour of WP6+ is following: if an attribute bit is set in the cell attributes, we cannot
 	// unset it; if it is set, we can set or unset it
@@ -1086,6 +1090,42 @@ void WPXContentListener::justificationChange(const uint8_t justification)
 	}
 }
 
+const float WPXContentListener::_getNextTabStop() const
+{
+	for (std::vector<WPXTabStop>::const_iterator iter = m_ps->m_tabStops.begin(); iter != (m_ps->m_tabStops.end() - 1); iter++)
+	{
+		if (iter->m_position
+			- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange))
+			== (m_ps->m_leftMarginByTabs + m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange))
+			return (iter+1)->m_position
+				- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange));
+		if (iter->m_position
+			- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange))
+			> (m_ps->m_leftMarginByTabs + m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange))
+			return iter->m_position
+				- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange));
+	}
+	return (std::numeric_limits<float>::min)();
+}
+
+const float WPXContentListener::_getPreviousTabStop() const
+{
+	for (std::vector<WPXTabStop>::reverse_iterator riter = m_ps->m_tabStops.rbegin(); riter != (m_ps->m_tabStops.rend() - 1); riter++)
+	{
+		if (riter->m_position
+			- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange))
+			== (m_ps->m_leftMarginByTabs + m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange))
+			return (riter+1)->m_position
+				- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange));
+		if (riter->m_position 
+			- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange))
+			< (m_ps->m_leftMarginByTabs + m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange))
+			return riter->m_position
+				- (m_ps->m_isTabPositionRelative ? 0.0f : (m_ps->m_pageMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_leftMarginByParagraphMarginChange));
+	}
+	return (std::numeric_limits<float>::max)();
+}
+
 WPXString WPXContentListener::_colorToString(const RGBSColor * color)
 {
 	WPXString tmpString;
