@@ -32,7 +32,7 @@ WPXMemoryInputStream::WPXMemoryInputStream(uint8_t *data, size_t size) :
 	m_offset(0),
 	m_size(size),
 	m_data(data),
-	m_tmpBuf(NULL)
+	m_tmpBuf(0)
 {
 }
 
@@ -46,9 +46,13 @@ WPXMemoryInputStream::~WPXMemoryInputStream()
 
 const uint8_t * WPXMemoryInputStream::read(size_t numBytes, size_t &numBytesRead)
 {
+	numBytesRead = 0;
+	if (0 == numBytes)
+		return 0;
+
 	if (m_tmpBuf)
 		delete [] m_tmpBuf;
-	m_tmpBuf = NULL;
+	m_tmpBuf = 0;
 	int numBytesToRead;
 
 	if ((m_offset+numBytes) < m_size)
@@ -59,10 +63,10 @@ const uint8_t * WPXMemoryInputStream::read(size_t numBytes, size_t &numBytesRead
 	numBytesRead = numBytesToRead; // about as paranoid as we can be..
 
 	if (numBytesToRead == 0)
-		return NULL;
+		return 0;
 
 	m_tmpBuf = new uint8_t[numBytesToRead];
-	for (size_t i=0; i<numBytesToRead; i++)
+	for (size_t i=0; (long)i<(long)numBytesToRead; i++)
 	{
 		m_tmpBuf[i] = m_data[m_offset];
 		m_offset++;
@@ -83,7 +87,7 @@ int WPXMemoryInputStream::seek(long offset, WPX_SEEK_TYPE seekType)
 		m_offset = 0;
 		return 1;
 	}
-	if (m_offset > m_size)
+	if ((long)m_offset > (long)m_size)
 	{
 		m_offset = m_size;
 		return 1;
@@ -99,7 +103,7 @@ long WPXMemoryInputStream::tell()
 
 bool WPXMemoryInputStream::atEOS()
 {
-	if (m_offset == m_size) 
+	if ((long)m_offset == (long)m_size) 
 		return true; 
 
 	return false;
